==> ldap-account-manager_8.0.1.orig.tar.bz2: ldap-account-manager-8.0.1/templates/lib/extra/ckeditor/plugins/table/lang/lt.js <==
/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'table', 'lt', {
	border: 'Rėmelio dydis',
	caption: 'Antraštė',
	cell: {
		menu: 'Langelis',
		insertBefore: 'Įterpti langelį prieš',
		insertAfter: 'Įterpti langelį po',
		deleteCell: 'Šalinti langelius',
		merge: 'Sujungti langelius',
		mergeRight: 'Sujungti su dešine',
		mergeDown: 'Sujungti su apačia',
		splitHorizontal: 'Skaidyti langelį horizontaliai',
		splitVertical: 'Skaidyti langelį vertikaliai',
		title: 'Cell nustatymai',
		cellType: 'Cell rūšis',
		rowSpan: 'Eilučių Span',
		colSpan: 'Stulpelių Span',
		wordWrap: 'Sutraukti raides',
		hAlign: 'Horizontalus lygiavimas',
		vAlign: 'Vertikalus lygiavimas',
		alignBaseline: 'Apatinė linija',
		bgColor: 'Fono spalva',
		borderColor: 'Rėmelio spalva',
		data: 'Data',
		header: 'Antraštė',
		yes: 'Taip',
		no: 'Ne',
		invalidWidth: 'Reikšmė turi būti skaičius.',
		invalidHeight: 'Reikšmė turi būti skaičius.',
		invalidRowSpan: 'Reikšmė turi būti skaičius.',
		invalidColSpan: 'Reikšmė turi būti skaičius.',
		chooseColor: 'Pasirinkite'
	},
	cellPad: 'Tarpas nuo langelio rėmo iki teksto',
	cellSpace: 'Tarpas tarp langelių',
	column: {
		menu: 'Stulpelis',
		insertBefore: 'Įterpti stulpelį prieš',
		insertAfter: 'Įterpti stulpelį po',
		deleteColumn: 'Šalinti stulpelius'
	},
	columns: 'Stulpeliai',
	deleteTable: 'Šalinti lentelę',
	headers: 'Antraštės',
	headersBoth: 'Abu',
	headersColumn: 'Pirmas stulpelis',
	headersNone: 'Nėra',
	headersRow: 'Pirma eilutė',
	heightUnit: 'height unit', // MISSING
	invalidBorder: 'Reikšmė turi būti nurodyta skaičiumi.',
	invalidCellPadding: 'Reikšmė turi būti nurodyta skaičiumi.',
	invalidCellSpacing: 'Reikšmė turi būti nurodyta skaičiumi.',
	invalidCols: 'Skaičius turi būti didesnis nei 0.',
	invalidHeight: 'Reikšmė turi būti nurodyta skaičiumi.',
	invalidRows: 'Skaičius turi būti didesnis nei 0.',
	invalidWidth: 'Reikšmė turi būti nurodyta skaičiumi.',
	menu: 'Lentelės savybės',
	row: {
		menu: 'Eilutė',
		insertBefore: 'Įterpti eilutę prieš',
		insertAfter: 'Įterpti eilutę po',
		deleteRow: 'Šalinti eilutes'
	},
	rows: 'Eilutės',
	summary: 'Santrauka',
	title: 'Lentelės savybės',
	toolbar: 'Lentelė',
	widthPc: 'procentais',
	widthPx: 'taškais',
	widthUnit: 'pločio vienetas'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/table/lang/lt.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'table', 'lt', {
	border: 'Rėmelio dydis',
	caption: 'Antraštė',
	cell: {
		menu: 'Langelis',
		insertBefore: 'Įterpti langelį prieš',
		insertAfter: 'Įterpti langelį po',
		deleteCell: 'Šalinti langelius',
		merge: 'Sujungti langelius',
		mergeRight: 'Sujungti su dešine',
		mergeDown: 'Sujungti su apačia',
		splitHorizontal: 'Skaidyti langelį horizontaliai',
		splitVertical: 'Skaidyti langelį vertikaliai',
		title: 'Cell nustatymai',
		cellType: 'Cell rūšis',
		rowSpan: 'Eilučių Span',
		colSpan: 'Stulpelių Span',
		wordWrap: 'Sutraukti raides',
		hAlign: 'Horizontalus lygiavimas',
		vAlign: 'Vertikalus lygiavimas',
		alignBaseline: 'Apatinė linija',
		bgColor: 'Fono spalva',
		borderColor: 'Rėmelio spalva',
		data: 'Data',
		header: 'Antraštė',
		columnHeader: 'Column Header', // MISSING
		rowHeader: 'Row Header', // MISSING
		yes: 'Taip',
		no: 'Ne',
		invalidWidth: 'Reikšmė turi būti skaičius.',
		invalidHeight: 'Reikšmė turi būti skaičius.',
		invalidRowSpan: 'Reikšmė turi būti skaičius.',
		invalidColSpan: 'Reikšmė turi būti skaičius.',
		chooseColor: 'Pasirinkite'
	},
	cellPad: 'Tarpas nuo langelio rėmo iki teksto',
	cellSpace: 'Tarpas tarp langelių',
	column: {
		menu: 'Stulpelis',
		insertBefore: 'Įterpti stulpelį prieš',
		insertAfter: 'Įterpti stulpelį po',
		deleteColumn: 'Šalinti stulpelius'
	},
	columns: 'Stulpeliai',
	deleteTable: 'Šalinti lentelę',
	headers: 'Antraštės',
	headersBoth: 'Abu',
	headersColumn: 'Pirmas stulpelis',
	headersNone: 'Nėra',
	headersRow: 'Pirma eilutė',
	heightUnit: 'height unit', // MISSING
	invalidBorder: 'Reikšmė turi būti nurodyta skaičiumi.',
	invalidCellPadding: 'Reikšmė turi būti nurodyta skaičiumi.',
	invalidCellSpacing: 'Reikšmė turi būti nurodyta skaičiumi.',
	invalidCols: 'Skaičius turi būti didesnis nei 0.',
	invalidHeight: 'Reikšmė turi būti nurodyta skaičiumi.',
	invalidRows: 'Skaičius turi būti didesnis nei 0.',
	invalidWidth: 'Reikšmė turi būti nurodyta skaičiumi.',
	menu: 'Lentelės savybės',
	row: {
		menu: 'Eilutė',
		insertBefore: 'Įterpti eilutę prieš',
		insertAfter: 'Įterpti eilutę po',
		deleteRow: 'Šalinti eilutes'
	},
	rows: 'Eilutės',
	summary: 'Santrauka',
	title: 'Lentelės savybės',
	toolbar: 'Lentelė',
	widthPc: 'procentais',
	widthPx: 'taškais',
	widthUnit: 'pločio vienetas'
} );
